@@ -3,7 +3,7 @@
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
-from trytond.backend import TableHandler
+from trytond import backend
 
 __all__ = ['ContactMechanism']
 
@@ -32,46 +32,42 @@ class ContactMechanism(ModelSQL, ModelView):
     _rec_name = 'value'
 
     type = fields.Selection(_TYPES, 'Type', required=True, states=STATES,
-        sort=False, on_change=['value', 'type'], depends=DEPENDS)
-    value = fields.Char('Value', select=True, states=STATES,
-        on_change=['value', 'type'], depends=DEPENDS)
+        sort=False, depends=DEPENDS)
+    value = fields.Char('Value', select=True, states=STATES, depends=DEPENDS)
     comment = fields.Text('Comment', states=STATES, depends=DEPENDS)
     party = fields.Many2One('party.party', 'Party', required=True,
         ondelete='CASCADE', states=STATES, select=True, depends=DEPENDS)
     active = fields.Boolean('Active', select=True)
-    sequence = fields.Integer('Sequence',
-        order_field='(%(table)s.sequence IS NULL) %(order)s, '
-        '%(table)s.sequence %(order)s')
+    sequence = fields.Integer('Sequence')
     email = fields.Function(fields.Char('E-Mail', states={
         'invisible': Eval('type') != 'email',
         'required': Eval('type') == 'email',
         'readonly': ~Eval('active', True),
-        }, on_change=['email', 'type'], depends=['value', 'type', 'active']),
+        }, depends=['value', 'type', 'active']),
         'get_value', setter='set_value')
     website = fields.Function(fields.Char('Website', states={
         'invisible': Eval('type') != 'website',
         'required': Eval('type') == 'website',
         'readonly': ~Eval('active', True),
-        }, on_change=['website', 'type'], depends=['value', 'type', 'active']),
+        }, depends=['value', 'type', 'active']),
         'get_value', setter='set_value')
     skype = fields.Function(fields.Char('Skype', states={
         'invisible': Eval('type') != 'skype',
         'required': Eval('type') == 'skype',
         'readonly': ~Eval('active', True),
-        }, on_change=['skype', 'type'], depends=['value', 'type', 'active']),
+        }, depends=['value', 'type', 'active']),
         'get_value', setter='set_value')
     sip = fields.Function(fields.Char('SIP', states={
         'invisible': Eval('type') != 'sip',
         'required': Eval('type') == 'sip',
         'readonly': ~Eval('active', True),
-        }, on_change=['sip', 'type'], depends=['value', 'type', 'active']),
+        }, depends=['value', 'type', 'active']),
         'get_value', setter='set_value')
     other_value = fields.Function(fields.Char('Value', states={
         'invisible': Eval('type').in_(['email', 'website', 'skype', 'sip']),
         'required': ~Eval('type').in_(['email', 'website']),
         'readonly': ~Eval('active', True),
-        }, on_change=['other_value', 'type'],
-            depends=['value', 'type', 'active']),
+        }, depends=['value', 'type', 'active']),
         'get_value', setter='set_value')
     url = fields.Function(fields.Char('URL', states={
                 'invisible': (~Eval('type').in_(['email', 'website', 'skype',
@@ -92,6 +88,7 @@ class ContactMechanism(ModelSQL, ModelView):
 
     @classmethod
     def __register__(cls, module_name):
+        TableHandler = backend.get('TableHandler')
         cursor = Transaction().cursor
         table = TableHandler(cursor, cls, module_name)
 
@@ -100,6 +97,11 @@ class ContactMechanism(ModelSQL, ModelView):
         # Migration from 2.4: drop required on sequence
         table.not_null_action('sequence', action='remove')
 
+    @staticmethod
+    def order_sequence(tables):
+        table, _ = tables[None]
+        return [table.sequence == None, table.sequence]
+
     @staticmethod
     def default_type():
         return 'phone'
@@ -143,33 +145,42 @@ class ContactMechanism(ModelSQL, ModelView):
             'url': self.get_url(value=value)
             }
 
+    @fields.depends('value', 'type')
     def on_change_type(self):
         return {
             'url': self.get_url(value=self.value),
             }
 
+    @fields.depends('value', 'type')
     def on_change_value(self):
         return self._change_value(self.value)
 
+    @fields.depends('website', 'type')
     def on_change_website(self):
         return self._change_value(self.website)
 
+    @fields.depends('email', 'type')
     def on_change_email(self):
         return self._change_value(self.email)
 
+    @fields.depends('skype', 'type')
     def on_change_skype(self):
         return self._change_value(self.skype)
 
+    @fields.depends('sip', 'type')
     def on_change_sip(self):
         return self._change_value(self.sip)
 
+    @fields.depends('other_value', 'type')
     def on_change_other_value(self):
         return self._change_value(self.other_value)
 
     @classmethod
-    def write(cls, mechanisms, vals):
-        if 'party' in vals:
-            for mechanism in mechanisms:
-                if mechanism.party.id != vals['party']:
-                    cls.raise_user_error('write_party', (mechanism.rec_name,))
-        super(ContactMechanism, cls).write(mechanisms, vals)
+    def write(cls, *args):
+        actions = iter(args)
+        for mechanisms, values in zip(actions, actions):
+            if 'party' in values:
+                for mechanism in mechanisms:
+                    if mechanism.party.id != values['party']:
+                        cls.raise_user_error('write_party', (mechanism.rec_name,))
+        super(ContactMechanism, cls).write(*args)
