@@ -1,13 +1,5 @@
-#!/usr/bin/env python
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-import sys
-import os
-DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
-    '..', '..', '..', '..', '..', 'trytond')))
-if os.path.isdir(DIR):
-    sys.path.insert(0, os.path.dirname(DIR))
-
 import unittest
 import trytond.tests.test_tryton
 from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view,\
@@ -16,9 +8,7 @@ from trytond.transaction import Transaction
 
 
 class PartyTestCase(unittest.TestCase):
-    '''
-    Test Party module.
-    '''
+    'Test Party module'
 
     def setUp(self):
         trytond.tests.test_tryton.install_module('party')
@@ -27,42 +17,34 @@ class PartyTestCase(unittest.TestCase):
         self.address = POOL.get('party.address')
 
     def test0005views(self):
-        '''
-        Test views.
-        '''
+        'Test views'
         test_view('party')
 
     def test0006depends(self):
-        '''
-        Test depends.
-        '''
+        'Test depends'
         test_depends()
 
     def test0010category(self):
-        '''
-        Create category.
-        '''
+        'Create category'
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            category1 = self.category.create({
-                'name': 'Category 1',
-                })
+            category1, = self.category.create([{
+                        'name': 'Category 1',
+                        }])
             self.assert_(category1.id)
             transaction.cursor.commit()
 
     def test0020category_recursion(self):
-        '''
-        Test category recursion.
-        '''
+        'Test category recursion'
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
             category1, = self.category.search([
                 ('name', '=', 'Category 1'),
                 ], limit=1)
 
-            category2 = self.category.create({
-                'name': 'Category 2',
-                'parent': category1.id,
-                })
+            category2, = self.category.create([{
+                        'name': 'Category 2',
+                        'parent': category1.id,
+                        }])
             self.assert_(category2.id)
 
             self.assertRaises(Exception, self.category.write,
@@ -71,29 +53,25 @@ class PartyTestCase(unittest.TestCase):
                 })
 
     def test0030party(self):
-        '''
-        Create party.
-        '''
+        'Create party'
         with Transaction().start(DB_NAME, USER,
                 context=CONTEXT) as transaction:
-            party1 = self.party.create({
-                'name': 'Party 1',
-                })
+            party1, = self.party.create([{
+                        'name': 'Party 1',
+                        }])
             self.assert_(party1.id)
             transaction.cursor.commit()
 
     def test0040party_code(self):
-        '''
-        Test party code constraint.
-        '''
+        'Test party code constraint'
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
             party1, = self.party.search([], limit=1)
 
             code = party1.code
 
-            party2 = self.party.create({
-                'name': 'Party 2',
-                })
+            party2, = self.party.create([{
+                        'name': 'Party 2',
+                        }])
 
             self.assertRaises(Exception, self.party.write,
                 [party2], {
@@ -101,17 +79,15 @@ class PartyTestCase(unittest.TestCase):
                 })
 
     def test0050address(self):
-        '''
-        Create address.
-        '''
+        'Create address'
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
             party1, = self.party.search([], limit=1)
 
-            address = self.address.create({
-                'party': party1.id,
-                'street': 'St sample, 15',
-                'city': 'City',
-                })
+            address, = self.address.create([{
+                        'party': party1.id,
+                        'street': 'St sample, 15',
+                        'city': 'City',
+                        }])
             self.assert_(address.id)
 
 
@@ -119,6 +95,3 @@ def suite():
     suite = trytond.tests.test_tryton.suite()
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(PartyTestCase))
     return suite
-
-if __name__ == '__main__':
-    unittest.TextTestRunner(verbosity=2).run(suite())
